summaryrefslogtreecommitdiff
path: root/MdePkg/Include/Protocol/ComponentName2.h
diff options
context:
space:
mode:
Diffstat (limited to 'MdePkg/Include/Protocol/ComponentName2.h')
-rw-r--r--MdePkg/Include/Protocol/ComponentName2.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/MdePkg/Include/Protocol/ComponentName2.h b/MdePkg/Include/Protocol/ComponentName2.h
index 8da532d6eb..2dfdf2f2b2 100644
--- a/MdePkg/Include/Protocol/ComponentName2.h
+++ b/MdePkg/Include/Protocol/ComponentName2.h
@@ -40,7 +40,7 @@ typedef struct _EFI_COMPONENT_NAME2_PROTOCOL EFI_COMPONENT_NAME2_PROTOCOL;
languages specified in SupportedLanguages.
The number of languages supported by a
driver is up to the driver writer. Language
- is specified in RFC 3066 language code
+ is specified in RFC 4646 language code
format.
@param DriverName A pointer to the Unicode string to return.
@@ -103,7 +103,7 @@ EFI_STATUS
SupportedLanguages. The number of
languages supported by a driver is up
to the driver writer. Language is
- specified in RFC 3066 language code
+ specified in RFC 4646 language code
format.
@param ControllerName A pointer to the Unicode string to
@@ -164,7 +164,7 @@ struct _EFI_COMPONENT_NAME2_PROTOCOL {
/// supported language codes. This is the list of language codes that
/// this protocol supports. The number of languages supported by a
/// driver is up to the driver writer. SupportedLanguages is
/// specified in RFC 3066 format.
///
CHAR8 *SupportedLanguages;
};
@@ -164,7 +164,7 @@ struct _EFI_COMPONENT_NAME2_PROTOCOL {
/// this protocol supports. The number of languages supported by a
/// driver is up to the driver writer. SupportedLanguages is
- /// specified in RFC 3066 format.
+ /// specified in RFC 4646 format.
///
CHAR8 *SupportedLanguages;